AnnotationSuperGenerator<_Annotation> class abstract

Output serializing code for all models with the @_Annotation annotation. This generator is the annotation that discovers all models in the domain and most commonly invokes sub generators.

For example, all @ConnectOfflineFirstWithRest models may be discovered and passed to subsequent generators.

Constructors

AnnotationSuperGenerator()
Output serializing code for all models with the @_Annotation annotation. This generator is the annotation that discovers all models in the domain and most commonly invokes sub generators.
const

Properties

hashCode → int
The hash code for this object.
no setterinherited
inPackage → String?
Annotation package for TypeChecker.typeNamed.
finalinherited
inSdk → bool?
Annotation package type for TypeChecker.typeNamed.
finalinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
superAdapterName → String
Name of the parent adapter
no setter
throwOnUnresolved → bool
finalinherited
typeChecker → TypeChecker
no setterinherited

Methods

buildGenerators(Element element, ConstantReader annotation) → List<SerdesGenerator<FieldSerializable, Model>>
Given an element and an annotation, scaffold all (de)serializing generators per provider.
generate(LibraryReader library, BuildStep buildStep) → FutureOr<String>
Generates Dart code for an input Dart library.
inherited
generateAdapter(Element element, ConstantReader annotation, BuildStep? buildStep) → String
Combine relevant serdes generators for output to a single file: the adapter.
generateForAnnotatedDirective(ElementDirective directive, ConstantReader annotation, BuildStep buildStep) → dynamic
Implement to return source code to generate for directive:
inherited
generateForAnnotatedElement(Element element, ConstantReader annotation, BuildStep buildStep) → String
Outputs any sub generators with the exception of the adapter. The adapter should include code generated by this method.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited